*-------------------------------------------------------------------------------------------------------------------------------------;

* CIS - Community Innovation Survey 3 - Data without Boundaries (Work Package 5);

* This routine converts CIS 3 Hungary data formatted in CSV into SAS7BDAT ;
* Checked for the July 2013 release of the CIS, as provided by Eurostat. ;

* Version 1 of the routine, March 2015;
* SAS 9.3;

* University of Ljubljana, Social Science Data Archives, partners of Data without Boundaries project;
* Sebastian Kocar;
* http://www.adp.fdv.uni-lj.si/;
* Contact: arhiv.podatkov@fdv.uni-lj.si;
*
* This SAS code is protected under the creative commons license. ;

*-------------------------------------------------------------------------------------------------------------------------------------;

* --- EXCEL DATA EXPORT---;

* To use this SAS code, CIS 3 Hungary Excel 1997-2003 data file has to be exported/saved as ;
* CSV data file in Microsoft Office Excel (with a comma as a separator and a dot as a decimal ;
* separator, with no exceptions!). ;
* PLEASE NOTE that decimal separators in Excel should be set to commas (,) before saving the dataset as;
* a CSV dataset. After that the following two actions should be done in that specific order using;
* a text editor: (1) replacing  commas (,) with dots (.), (2) replacing semicolons (;) with commas (,).;
* The database in .csv format should then be imported into SAS and later processed using  the;
* commands below. ;

*-------------------------------------------------------------------------------------------------------------------------------------;


* --- CONFIGURATION SECTION - START ---                                          ;


* The following command should contain the complete path and                     ;
* name of the .csv file to be read (e.g. "C:/CIS2008/Data/ALL.csv")              ;
* Change CSV_DATA_PATH to your filename, below                                   ;

FILENAME csvpath "CSV_DATA_PATH";


* The following command should contain the complete path of the                  ;
* directory where the setup file will be saved (e.g. "C:/CIS2008/Data")          ;
* Change SAS_DATA_FOLDER to your directory name, below                           ;

LIBNAME dirout "SAS_DATA_FOLDER";


* The following command should contain the name of the output SAS file only      ;
* (without quotes, and without the .sas7bdat extension)                          ;
* Change SAS_FILE_NAME to your output file name, below                           ;

%LET sasfile=SAS_FILE_NAME;


* --- CONFIGURATION SECTION -  END ---                                           ;

* ------------------------------------------------------------------------------ ;



* There should be nothing to change below this line;
* ------------------------------------------------------------------------------ ;



* --- Read the raw data file ---                                                 ;

DATA sasimport;

INFILE csvpath
       DLM=","
       FIRSTOBS=2
       DSD
       TRUNCOVER
       LRECL=512
       ;

INPUT  SIZE98_N $
       SIZE00_N $
       NACE2_N $
       NUTS_2DIG $
       C_HO
       GP
       EST
       TURNINC
       TURNDEC
       SIGMAR
       INPDT
       INPDTW
       TURNIN
       TURNUNG
       INMAR
       TURNMAR
       INPCS
       INPCSW
       INON
       INAB
       RRDIN
       RRDEX
       RMAC
       ROEK
       RTR
       RMAR
       RPRE
       RDENG
       ERANGE
       EMAR
       EQUA
       EFLEX
       ECAP
       ELBR
       EMAT
       EENV
       ESTD
       FUNLOC
       FUNGMT
       FUNEU
       FUNRTD
       CO
       CO11
       CO12
       CO13
       CO14
       CO15
       CO16
       CO21
       CO22
       CO23
       CO24
       CO25
       CO26
       CO31
       CO32
       CO33
       CO34
       CO35
       CO36
       CO41
       CO42
       CO43
       CO44
       CO45
       CO46
       CO51
       CO52
       CO53
       CO54
       CO55
       CO56
       CO61
       CO62
       CO63
       CO64
       CO65
       CO66
       CO71
       CO72
       CO73
       CO74
       CO75
       CO76
       CO81
       CO82
       CO83
       CO84
       CO85
       CO86
       SENT
       SGRP
       SSUP
       SCLI
       SCOM
       SUNI
       SGMT
       SPRO
       SEXB
       HDLAY
       HSTAR
       HBUR
       HPRIOR
       HMAR
       HIMP
       HECO
       HCOS
       HFIN
       HORG
       HPER
       HTEC
       HINF
       HFLEX
       HCUS
       PAAP
       PAVAL
       PROREG
       PROTM
       PROCP
       PROSEC
       PRODES
       PROTIM
       ACTSTR
       ACTMAN
       ACTORG
       ACTMAR
       ACTAES
       W2USE
       TURN98 $
       EXP98
       TURN
       EXP $
       INVTA $
       RRDINX $
       RRDEXX $
       RMACX $
       ROEKX $
       ROTHX $
       RTOT $
       RDPER $
       EMPHI $
       ;
RUN;

* ------------------------------------------------------------------------------ ;


* --- Recode string variables which have labels, to numeric variables ---        ;

DATA sasimport;

    SET sasimport;

    IF (NACE2_N = '10') THEN TEMPVAR = 1;
    IF (NACE2_N = '10_11') THEN TEMPVAR = 2;
    IF (NACE2_N = '10_11_12') THEN TEMPVAR = 3;
    IF (NACE2_N = '10_11_13') THEN TEMPVAR = 4;
    IF (NACE2_N = '10_11_14') THEN TEMPVAR = 5;
    IF (NACE2_N = '10_14') THEN TEMPVAR = 6;
    IF (NACE2_N = '11_12_14') THEN TEMPVAR = 7;
    IF (NACE2_N = '11_14') THEN TEMPVAR = 8;
    IF (NACE2_N = '12_13') THEN TEMPVAR = 9;
    IF (NACE2_N = '13_14') THEN TEMPVAR = 10;
    IF (NACE2_N = '14') THEN TEMPVAR = 11;
    IF (NACE2_N = '14_15') THEN TEMPVAR = 12;
    IF (NACE2_N = '15') THEN TEMPVAR = 13;
    IF (NACE2_N = '15_15') THEN TEMPVAR = 14;
    IF (NACE2_N = '15_16') THEN TEMPVAR = 15;
    IF (NACE2_N = '16') THEN TEMPVAR = 16;
    IF (NACE2_N = '17') THEN TEMPVAR = 17;
    IF (NACE2_N = '17_18') THEN TEMPVAR = 18;
    IF (NACE2_N = '18') THEN TEMPVAR = 19;
    IF (NACE2_N = '18_19') THEN TEMPVAR = 20;
    IF (NACE2_N = '19') THEN TEMPVAR = 21;
    IF (NACE2_N = '19_20') THEN TEMPVAR = 22;
    IF (NACE2_N = '20') THEN TEMPVAR = 23;
    IF (NACE2_N = '20_21') THEN TEMPVAR = 24;
    IF (NACE2_N = '20_21_22') THEN TEMPVAR = 25;
    IF (NACE2_N = '21') THEN TEMPVAR = 26;
    IF (NACE2_N = '22') THEN TEMPVAR = 27;
    IF (NACE2_N = '22_23') THEN TEMPVAR = 28;
    IF (NACE2_N = '23') THEN TEMPVAR = 29;
    IF (NACE2_N = '23_24') THEN TEMPVAR = 30;
    IF (NACE2_N = '24') THEN TEMPVAR = 31;
    IF (NACE2_N = '24_25') THEN TEMPVAR = 32;
    IF (NACE2_N = '25') THEN TEMPVAR = 33;
    IF (NACE2_N = '26') THEN TEMPVAR = 34;
    IF (NACE2_N = '26_27') THEN TEMPVAR = 35;
    IF (NACE2_N = '27') THEN TEMPVAR = 36;
    IF (NACE2_N = '27_28') THEN TEMPVAR = 37;
    IF (NACE2_N = '28') THEN TEMPVAR = 38;
    IF (NACE2_N = '29') THEN TEMPVAR = 39;
    IF (NACE2_N = '30') THEN TEMPVAR = 40;
    IF (NACE2_N = '30_31') THEN TEMPVAR = 41;
    IF (NACE2_N = '31') THEN TEMPVAR = 42;
    IF (NACE2_N = '31_33') THEN TEMPVAR = 43;
    IF (NACE2_N = '32') THEN TEMPVAR = 44;
    IF (NACE2_N = '33') THEN TEMPVAR = 45;
    IF (NACE2_N = '33_34') THEN TEMPVAR = 46;
    IF (NACE2_N = '34') THEN TEMPVAR = 47;
    IF (NACE2_N = '34_35') THEN TEMPVAR = 48;
    IF (NACE2_N = '35') THEN TEMPVAR = 49;
    IF (NACE2_N = '36') THEN TEMPVAR = 50;
    IF (NACE2_N = '36_37') THEN TEMPVAR = 51;
    IF (NACE2_N = '36_40_41') THEN TEMPVAR = 52;
    IF (NACE2_N = '37') THEN TEMPVAR = 53;
    IF (NACE2_N = '40') THEN TEMPVAR = 54;
    IF (NACE2_N = '40_41') THEN TEMPVAR = 55;
    IF (NACE2_N = '41') THEN TEMPVAR = 56;
    IF (NACE2_N = '51') THEN TEMPVAR = 57;
    IF (NACE2_N = '60') THEN TEMPVAR = 58;
    IF (NACE2_N = '60_61') THEN TEMPVAR = 59;
    IF (NACE2_N = '60_61_62') THEN TEMPVAR = 60;
    IF (NACE2_N = '61') THEN TEMPVAR = 61;
    IF (NACE2_N = '61_62') THEN TEMPVAR = 62;
    IF (NACE2_N = '62') THEN TEMPVAR = 63;
    IF (NACE2_N = '62_63') THEN TEMPVAR = 64;
    IF (NACE2_N = '63') THEN TEMPVAR = 65;
    IF (NACE2_N = '63_64') THEN TEMPVAR = 66;
    IF (NACE2_N = '64') THEN TEMPVAR = 67;
    IF (NACE2_N = '64_65_66_67') THEN TEMPVAR = 68;
    IF (NACE2_N = '65') THEN TEMPVAR = 69;
    IF (NACE2_N = '65_66_67') THEN TEMPVAR = 70;
    IF (NACE2_N = '66') THEN TEMPVAR = 71;
    IF (NACE2_N = '66_67') THEN TEMPVAR = 72;
    IF (NACE2_N = '67') THEN TEMPVAR = 73;
    IF (NACE2_N = '72') THEN TEMPVAR = 74;
    IF (NACE2_N = '72_73') THEN TEMPVAR = 75;
    IF (NACE2_N = '73') THEN TEMPVAR = 76;
    IF (NACE2_N = '74') THEN TEMPVAR = 77;

RUN;

DATA sasimport;

    SET sasimport;

    DROP NACE2_N;
    RENAME TEMPVAR = NACE2_N;

RUN;

DATA sasimport;

    SET sasimport;

    IF (size98_N = '       0') THEN TEMPVAR = 1;
    IF (size98_N = '       1') THEN TEMPVAR = 2;
    IF (size98_N = '       2') THEN TEMPVAR = 3;
    IF (size98_N = '       3') THEN TEMPVAR = 4;
    IF (size98_N = '0_1') THEN TEMPVAR = 5;
    IF (size98_N = '0_1_2') THEN TEMPVAR = 6;
    IF (size98_N = '0_1_2_3') THEN TEMPVAR = 7;
    IF (size98_N = '0_1_2.3') THEN TEMPVAR = 8;
    IF (size98_N = '0_1_3') THEN TEMPVAR = 9;
    IF (size98_N = '0_2') THEN TEMPVAR = 10;
    IF (size98_N = '0_2_3') THEN TEMPVAR = 11;
    IF (size98_N = '0.1_2') THEN TEMPVAR = 12;
    IF (size98_N = '1_2') THEN TEMPVAR = 13;
    IF (size98_N = '1_2_3') THEN TEMPVAR = 14;
    IF (size98_N = '1_3') THEN TEMPVAR = 15;
    IF (size98_N = '2_3') THEN TEMPVAR = 16;

RUN;

DATA sasimport;

    SET sasimport;

    DROP size98_N;
    RENAME TEMPVAR = size98_N;

RUN;

DATA sasimport;

    SET sasimport;

    IF (size00_N = '       1') THEN TEMPVAR = 1;
    IF (size00_N = '       2') THEN TEMPVAR = 2;
    IF (size00_N = '       3') THEN TEMPVAR = 3;
    IF (size00_N = '1_2') THEN TEMPVAR = 4;
    IF (size00_N = '1_2_3') THEN TEMPVAR = 5;
    IF (size00_N = '1_3') THEN TEMPVAR = 6;
    IF (size00_N = '2_3') THEN TEMPVAR = 7;

RUN;

DATA sasimport;

    SET sasimport;

    DROP size00_N;
    RENAME TEMPVAR = size00_N;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Force variables as numeric ---                                             ;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(TURN98, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP TURN98;
    RENAME TEMPVAR = TURN98;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(EXP, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP EXP;
    RENAME TEMPVAR = EXP;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(INVTA, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP INVTA;
    RENAME TEMPVAR = INVTA;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(RRDINX, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP RRDINX;
    RENAME TEMPVAR = RRDINX;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(RRDEXX, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP RRDEXX;
    RENAME TEMPVAR = RRDEXX;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(RMACX, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP RMACX;
    RENAME TEMPVAR = RMACX;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(ROEKX, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP ROEKX;
    RENAME TEMPVAR = ROEKX;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(ROTHX, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP ROTHX;
    RENAME TEMPVAR = ROTHX;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(RTOT, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP RTOT;
    RENAME TEMPVAR = RTOT;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(RDPER, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP RDPER;
    RENAME TEMPVAR = RDPER;

RUN;

DATA sasimport;

    SET sasimport;

    TEMPVAR = INPUT(EMPHI, ?? best.);

RUN;

DATA sasimport;

    SET sasimport;

    DROP EMPHI;
    RENAME TEMPVAR = EMPHI;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Reorder the variables in their original positions ---                      ;

DATA sasimport;

    RETAIN NUTS_2DIG NACE2_N GP C_HO EST TURNINC TURNDEC SIGMAR TURN98 TURN
           EXP98 EXP INVTA SIZE98_N SIZE00_N EMPHI INPDT INPDTW TURNIN TURNUNG
           INMAR TURNMAR INPCS INPCSW INON INAB RRDIN RRDINX RRDEX RRDEXX
           RMAC RMACX ROEK ROEKX RTR RMAR RPRE ROTHX RTOT RDPER RDENG ERANGE
           EMAR EQUA EFLEX ECAP ELBR EMAT EENV ESTD FUNLOC FUNGMT FUNEU
           FUNRTD CO CO11 CO12 CO13 CO14 CO15 CO16 CO21 CO22 CO23 CO24
           CO25 CO26 CO31 CO32 CO33 CO34 CO35 CO36 CO41 CO42 CO43 CO44
           CO45 CO46 CO51 CO52 CO53 CO54 CO55 CO56 CO61 CO62 CO63 CO64
           CO65 CO66 CO71 CO72 CO73 CO74 CO75 CO76 CO81 CO82 CO83 CO84
           CO85 CO86 SENT SGRP SSUP SCLI SCOM SUNI SGMT SPRO SEXB HDLAY
           HSTAR HBUR HPRIOR HMAR HIMP HECO HCOS HFIN HORG HPER HTEC HINF
           HFLEX HCUS PAAP PAVAL PROREG PROTM PROCP PROSEC PRODES PROTIM
           ACTSTR ACTMAN ACTORG ACTMAR ACTAES W2USE;

    SET sasimport;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Add Variable Labels --- ;
*--- Please note that the reference period is not 1998-2000 for all countries. Please check CIS 3 ;
* country level metadata.;


DATA sasimport;

    SET sasimport;

    LABEL NUTS_2DIG = "Country";
    LABEL NACE2_N   = "Main activity";
    LABEL GP        = "Enterprise part of a group";
    LABEL C_HO      = "Country of head office";
    LABEL EST       = "Establishment of enterprise between 1998 and 2000";
    LABEL TURNINC   = "Turnover increased 1998-2000";
    LABEL TURNDEC   = "Turnover decreased 1998-2000";
    LABEL SIGMAR    = "Most significant markets in 1998-2000";
    LABEL TURN98    = "Total turnover in 1998";
    LABEL TURN      = "Total turnover in 2000";
    LABEL EXP98     = "Export in 1998";
    LABEL EXP       = "Export in 2000";
    LABEL INVTA     = "Gross investment in tangible goods in 2000";
    LABEL SIZE98_N  = "Total number of employees in 1998";
    LABEL SIZE00_N  = "Total number of employees in 2000";
    LABEL EMPHI     = "Total number of employees in 2000, of which: with higher education";
    LABEL INPDT     = "Introduced onto the market a new or significantly improved goods or services";
    LABEL INPDTW    = "Who mainly developed these products";
    LABEL TURNIN    = "% of turnover in  unchanged or marginally modified products during 1998-2000 that were new to the firm";
    LABEL TURNUNG   = "% of turnover in  unchanged or marginally modified products during 1998-2000";
    LABEL INMAR     = "Introducing new or significantly improved products, new for the enterprise's market";
    LABEL TURNMAR   = "% of turnover in new or improved products introduced during 1998-2000 that were new to the market";
    LABEL INPCS     = "Introduced onto the market a new or significantly improved method of production";
    LABEL INPCSW    = "Who mainly developed these processes";
    LABEL INON      = "Enterprise with ongoing or abandoned innovation activities";
    LABEL INAB      = "Abandoned or suspended before completion";
    LABEL RRDIN     = "Engagement in intramural R&D";
    LABEL RRDINX    = "Expenditure in intramural R&D";
    LABEL RRDEX     = "Engagement in extramural R&D";
    LABEL RRDEXX    = "Purchase of extramural R&D";
    LABEL RMAC      = "Engagement in acquisition of machinery";
    LABEL RMACX     = "Expenditure in acquisition of machinery";
    LABEL ROEK      = "Engagement in acquisition of external knowledge";
    LABEL ROEKX     = "Expenditure in acquisition of external knowledge";
    LABEL RTR       = "Engagement in training for innovative activities";
    LABEL RMAR      = "Engagement in market introduction of innovation";
    LABEL RPRE      = "Engagement in other preparation";
    LABEL ROTHX     = "Other expenditure (in training, market innovation, design)";
    LABEL RTOT      = "Total of these four innovation expenditure categories";
    LABEL RDPER     = "People involved in R&D in 2000";
    LABEL RDENG     = "Type of engagement in R&D";
    LABEL ERANGE    = "Increased range of goods or services";
    LABEL EMAR      = "Increased market or market share";
    LABEL EQUA      = "Improved quality in goods or services";
    LABEL EFLEX     = "Improved production flexibility";
    LABEL ECAP      = "Improved production capacity";
    LABEL ELBR      = "Reduced labour costs per produced unit";
    LABEL EMAT      = "Reduced materials and energy per produced unit";
    LABEL EENV      = "Reduced environmental impact or health and safety aspects";
    LABEL ESTD      = "Met regulations or standards";
    LABEL FUNLOC    = "Public funding from local or regional authorities";
    LABEL FUNGMT    = "Public funding from central government";
    LABEL FUNEU     = "Public funding from the EU";
    LABEL FUNRTD    = "Funding from EU's 4th, 5th, 6th or 7th Framework Programme for RTD";
    LABEL CO        = "Cooperation arrangements on innovation activities";
    LABEL CO11      = "Other enterprises within enterprise group : National";
    LABEL CO12      = "Other enterprises within enterprise group : EU/EFTA";
    LABEL CO13      = "Other enterprises within enterprise group : EU-CC";
    LABEL CO14      = "Other enterprises within enterprise group : US";
    LABEL CO15      = "Other enterprises within enterprise group : Japan";
    LABEL CO16      = "Other enterprises within enterprise group : Other countries";
    LABEL CO21      = "Suppliers of equipment, etc. : National";
    LABEL CO22      = "Suppliers of equipment, etc. : EU/EFTA";
    LABEL CO23      = "Suppliers of equipment, etc. : EU-CC";
    LABEL CO24      = "Suppliers of equipment, etc. : US";
    LABEL CO25      = "Suppliers of equipment, etc. : Japan";
    LABEL CO26      = "Suppliers of equipment, etc. :  Other countries";
    LABEL CO31      = "Clients or customers : National";
    LABEL CO32      = "Clients or customers : EU/EFTA";
    LABEL CO33      = "Clients or customers : EU-CC";
    LABEL CO34      = "Clients or customers : US";
    LABEL CO35      = "Clients or customers : Japan";
    LABEL CO36      = "Clients or customers : Other countries";
    LABEL CO41      = "Competitors or other firms  : National";
    LABEL CO42      = "Competitors or other firms  : EU/EFTA";
    LABEL CO43      = "Competitors or other firms  : EU-CC";
    LABEL CO44      = "Competitors or other firms  : US";
    LABEL CO45      = "Competitors or other firms  : Japan";
    LABEL CO46      = "Competitors or other firms  : Other countries";
    LABEL CO51      = "Consultants: National";
    LABEL CO52      = "Consultants: EU/EFTA";
    LABEL CO53      = "Consultants: EU-CC";
    LABEL CO54      = "Consultants: US";
    LABEL CO55      = "Consultants: Japan";
    LABEL CO56      = "Consultants: Other countries";
    LABEL CO61      = "Commercial laboratories /R&D enterprises : National";
    LABEL CO62      = "Commercial laboratories /R&D enterprises : EU/EFTA";
    LABEL CO63      = "Commercial laboratories /R&D enterprises : EU-CC";
    LABEL CO64      = "Commercial laboratories /R&D enterprises : US";
    LABEL CO65      = "Commercial laboratories /R&D enterprises : Japan";
    LABEL CO66      = "Commercial laboratories /R&D enterprises : Other countries";
    LABEL CO71      = "Universities or other  : National";
    LABEL CO72      = "Universities or other  : EU/EFTA";
    LABEL CO73      = "Universities or other  : EU-CC";
    LABEL CO74      = "Universities or other  : US";
    LABEL CO75      = "Universities or other  : Japan";
    LABEL CO76      = "Universities or other  : Other countries";
    LABEL CO81      = "Government or public research institutes: National";
    LABEL CO82      = "Government or public research institutes:  EU/EFTA";
    LABEL CO83      = "Government or public research institutes:  EU-CC";
    LABEL CO84      = "Government or public research institutes: US";
    LABEL CO85      = "Government or public research institutes: Japan";
    LABEL CO86      = "Government or public research institutes: Other countries";
    LABEL SENT      = "Sources from within the enterprise";
    LABEL SGRP      = "Sources from other enterprises within the enterprise group";
    LABEL SSUP      = "Sources from Suppliers of equipment, materials, etc.";
    LABEL SCLI      = "Sources from Clients or customers";
    LABEL SCOM      = "Sources from Competitors and other enterprises of same industry";
    LABEL SUNI      = "Sources from Universities or other higher education institutes";
    LABEL SGMT      = "Sources from Government or public research institutes";
    LABEL SPRO      = "Sources from Professional and industry associations";
    LABEL SEXB      = "Sources from fairs, exhibitions";
    LABEL HDLAY     = "Innovation activity seriously delayed";
    LABEL HSTAR     = "Innovation activity prevented to be started";
    LABEL HBUR      = "Innovation activity burdened/cumbered with other serious problems";
    LABEL HPRIOR    = "No innovation activity due to prior innovations";
    LABEL HMAR      = "No innovation activity due to no demand for innovations";
    LABEL HIMP      = "No innovation activity due to factors impeding innovation?";
    LABEL HECO      = "Hampering factor : Excessive perceived economic risks";
    LABEL HCOS      = "Hampering factor : Innovation costs too high";
    LABEL HFIN      = "Hampering factor : Lack of appropriate sources of finance";
    LABEL HORG      = "Hampering factor : Organisational rigidities within the enterprise";
    LABEL HPER      = "Hampering factor : Lack of qualified personnel";
    LABEL HTEC      = "Hampering factor : Lack of information on technology";
    LABEL HINF      = "Hampering factor : Lack of information on markets";
    LABEL HFLEX     = "Hampering factor : Insufficient flexibility of regulations or standards";
    LABEL HCUS      = "Hampering factor : Lack of customer responsiveness to new goods or services";
    LABEL PAAP      = "Applied for a patent";
    LABEL PAVAL     = "Having valid patents";
    LABEL PROREG    = "Registration of design patterns";
    LABEL PROTM     = "Register a trademark";
    LABEL PROCP     = "Claimed copyright";
    LABEL PROSEC    = "Protecting inventions or innovations by Secrecy";
    LABEL PRODES    = "Protecting inventions or innovations by Complexity of design";
    LABEL PROTIM    = "Protecting inventions or innovations by Lead-time advantage on competitors";
    LABEL ACTSTR    = "Strategical changes";
    LABEL ACTMAN    = "Management changes";
    LABEL ACTORG    = "Organizational changes";
    LABEL ACTMAR    = "Marketing changes";
    LABEL ACTAES    = "Aesthetic changes (or other subjective changes)";
    LABEL W2USE     = "Weighting factor";

RUN;

* ------------------------------------------------------------------------------ ;


* --- Create value labels groups ---                                             ;

PROC FORMAT;

VALUE LABELS_1_GROUP
      0="No answer"
      1="Home Country"
      2="EU, EFTA, CC"
      3="rest of the world";

VALUE LABELS_2_GROUP
      0="No"
      1="Yes";

VALUE LABELS_3_GROUP
      1="Local/ regional (within a distance of around 50 km) within your country"
      2="Local/ regional (within a distance of around 50 km) within your neighbouring countries"
      3="National (with a distance of more than 50 km)"
      4="International (with a distance of more than 50 km)";

VALUE LABELS_4_GROUP
      1="Mainly your enterprise or enterprise group"
      2="Your enterprise in co-operation with other enterprises or institutions"
      3="Mainly other enterprises or institutions";

VALUE LABELS_5_GROUP
      1="Continuously"
      2="Occasionally";

VALUE LABELS_6_GROUP
      0="Not relevant"
      1="Low"
      2="Med"
      3="High";

VALUE LABELS_7_GROUP
      0="Not selected"
      1="Selected";

VALUE LABELS_8_GROUP
      0="Not used"
      1="Low"
      2="Med"
      3="High";

VALUE LABELS_9_GROUP
      1="Mining of coal and lignite; extraction of peat"
      2="Mining of coal, lignite; extraction of peat, crude petroleum, gas; service activities incidental to oil, gas extraction"
      3="Mining and quarrying of energy producing materials"
      4="Mining of coal, lignite, uranium, metal ores; extraction of peat, crude petroleum and natural gas"
      5="Mining of coal, lignite, uranium, other mining; extraction of peat, crude petroleum and natural gas"
      6="Mining of coal and lignite; extraction of peat; other mining and quarrying"
      7="Extraction of crude petroleum and natural gas; Mining of uranium and thorium ores; Other mining and quarrying"
      8="Extraction of crude petroleum and natural gas; Other mining and quarrying"
      9="Mining of uranium and thorium ores; Mining of metal ores"
      10="Mining and quarrying, except of energy producing materials"
      11="Other mining and quarrying"
      12="Other mining and quarrying; Manufacture of food products and beverages"
      13="Manufacture of food products and beverages"
      14="Manufacture of food products, beverages and tobacco (Portuguese coding)"
      15="Manufacture of food products, beverages and tobacco"
      16="Manufacture of tobacco products"
      17="Manufacture of textiles"
      18="Manufacture of textiles and textile products"
      19="Manufacture of wearing apparel; dressing and dyeing of fur"
      20="Manufacture of wearing apparel, luggage/handbags/saddlery/harness/footwear; dressing, dyeing of fur; tanning of leather"
      21="Manufacture of leather and leather products"
      22="Manufacture of leather and leather products; Manufacture of wood and wood products"
      23="Manufacture of wood and wood products"
      24="Manufacture of wood and wood products; Manufacture of pulp, paper and paper products"
      25="Manufacture of wood and wood products; Manufacture of pulp, paper and paper products; publishing and printing"
      26="Manufacture of pulp, paper and paper products"
      27="Publishing, printing and reproduction of recorded media"
      28="Publishing, printing , reproduction of recorded media;  Manufacture of coke, refined petroleum products and nuclear fuel"
      29="Manufacture of coke, refined petroleum products and nuclear fuel"
      30="Manufacture of coke, refined petroleum products and nuclear fuel; Manufacture of chemicals and chemical products"
      31="Manufacture of chemicals and chemical products"
      32="Manufacture of chemicals and chemical products; Manufacture of rubber and plastic products"
      33="Manufacture of rubber and plastic products"
      34="Manufacture of other non-metallic mineral products"
      35="Manufacture of other non-metallic mineral products;  Manufacture of basic metals"
      36="Manufacture of basic metals"
      37="Manufacture of basic metals and fabricated metal products"
      38="Manufacture of fabricated metal products, except machinery and equipment"
      39="Manufacture of machinery and equipment n.e.c."
      40="Manufacture of office machinery and computers"
      41="Manufacture of office machinery and computers; manufacture of electrical machinery and apparatus n.e.c."
      42="Manufacture of electrical machinery and apparatus n.e.c."
      43="Manufacture of electrical machinery and apparatus n.e.c.; medical, precision and optical instruments, watches and clocks"
      44="Manufacture of radio, television and communication equipment and apparatus"
      45="Manufacture of medical, precision and optical instruments, watches and clocks"
      46="Manufacture of medical, precision and optical instruments, watches, clocks; of motor vehicles, trailers, semi-trailers"
      47="Manufacture of motor vehicles, trailers and semi-trailers"
      48="Manufacture of transport equipment"
      49="Manufacture of other transport equipment"
      50="Manufacture of furniture; manufacturing n.e.c."
      51="Manufacture of furniture; manufacturing n.e.c.; Recycling"
      52="Manufacture of furniture; manufacturing n.e.c.;  Electricity, gas and water supply"
      53="Recycling"
      54="Electricity, gas, steam and hot water supply"
      55="Electricity, gas, steam and hot water supply; collection, purification and distribution of water"
      56="Collection, purification and distribution of water"
      57="Wholesale trade and commission trade, except of motor vehicles and motorcycles"
      58="Land transport; transport via pipelines"
      59="Land transport; transport via pipelines; Water transport"
      60="Land transport; transport via pipelines; Water transport; Air transport"
      61="Water transport"
      62="Water transport; Air transport"
      63="Air transport"
      64="Air transport; Supporting and auxiliary transport activities; activities of travel agencies"
      65="Supporting and auxiliary transport activities; activities of travel agencies"
      66="Supporting and auxiliary transport activities; activities of travel agencies; Post and telecommunications"
      67="Post and telecommunications"
      68="Post and telecommunications; Financial intermediation"
      69="Financial intermediation, except insurance and pension funding"
      70="Financial intermediation"
      71="Insurance and pension funding, except compulsory social security"
      72="Insurance and pension funding, except compulsory social security;  Activities auxiliary to financial intermediation"
      73="Activities auxiliary to financial intermediation"
      74="Computer and related activities"
      75="Computer and related activities; Research and development"
      76="Research and development"
      77="Other business activities";

VALUE LABELS_10_GROUP
      1="10-19"
      2="20-49"
      3="50-249"
      4="250+"
      5="10-49"
      6="10-249"
      7="10+"
      8="10+"
      9="10-49 & 250+"
      10="10-19 & 50-249"
      11="10-19 & 50+"
      12="10-249"
      13="20-249"
      14="20+"
      15="20-49 & 250+"
      16="50+";

VALUE LABELS_11_GROUP
      1="10-49"
      2="50-249"
      3="250+"
      4="10-249"
      5="10+"
      6="10-49 & 250+"
      7="50+";

RUN;

* ------------------------------------------------------------------------------ ;


* --- Format variables with value labels ---                                     ;

DATA sasimport;

    SET sasimport;

    FORMAT
    C_HO      LABELS_1_GROUP.
    GP        LABELS_2_GROUP.
    EST       LABELS_2_GROUP.
    TURNINC   LABELS_2_GROUP.
    TURNDEC   LABELS_2_GROUP.
    INPDT     LABELS_2_GROUP.
    INMAR     LABELS_2_GROUP.
    INPCS     LABELS_2_GROUP.
    INON      LABELS_2_GROUP.
    INAB      LABELS_2_GROUP.
    RRDIN     LABELS_2_GROUP.
    RRDEX     LABELS_2_GROUP.
    RMAC      LABELS_2_GROUP.
    ROEK      LABELS_2_GROUP.
    RTR       LABELS_2_GROUP.
    RMAR      LABELS_2_GROUP.
    RPRE      LABELS_2_GROUP.
    FUNLOC    LABELS_2_GROUP.
    FUNGMT    LABELS_2_GROUP.
    FUNEU     LABELS_2_GROUP.
    FUNRTD    LABELS_2_GROUP.
    CO        LABELS_2_GROUP.
    HDLAY     LABELS_2_GROUP.
    HSTAR     LABELS_2_GROUP.
    HBUR      LABELS_2_GROUP.
    HPRIOR    LABELS_2_GROUP.
    HMAR      LABELS_2_GROUP.
    HIMP      LABELS_2_GROUP.
    PAAP      LABELS_2_GROUP.
    PAVAL     LABELS_2_GROUP.
    PROREG    LABELS_2_GROUP.
    PROTM     LABELS_2_GROUP.
    PROCP     LABELS_2_GROUP.
    PROSEC    LABELS_2_GROUP.
    PRODES    LABELS_2_GROUP.
    PROTIM    LABELS_2_GROUP.
    ACTSTR    LABELS_2_GROUP.
    ACTMAN    LABELS_2_GROUP.
    ACTORG    LABELS_2_GROUP.
    ACTMAR    LABELS_2_GROUP.
    ACTAES    LABELS_2_GROUP.
    SIGMAR    LABELS_3_GROUP.
    INPDTW    LABELS_4_GROUP.
    INPCSW    LABELS_4_GROUP.
    RDENG     LABELS_5_GROUP.
    ERANGE    LABELS_6_GROUP.
    EMAR      LABELS_6_GROUP.
    EQUA      LABELS_6_GROUP.
    EFLEX     LABELS_6_GROUP.
    ECAP      LABELS_6_GROUP.
    ELBR      LABELS_6_GROUP.
    EMAT      LABELS_6_GROUP.
    EENV      LABELS_6_GROUP.
    ESTD      LABELS_6_GROUP.
    HECO      LABELS_6_GROUP.
    HCOS      LABELS_6_GROUP.
    HFIN      LABELS_6_GROUP.
    HORG      LABELS_6_GROUP.
    HPER      LABELS_6_GROUP.
    HTEC      LABELS_6_GROUP.
    HINF      LABELS_6_GROUP.
    HFLEX     LABELS_6_GROUP.
    HCUS      LABELS_6_GROUP.
    CO11      LABELS_7_GROUP.
    CO12      LABELS_7_GROUP.
    CO13      LABELS_7_GROUP.
    CO14      LABELS_7_GROUP.
    CO15      LABELS_7_GROUP.
    CO16      LABELS_7_GROUP.
    CO21      LABELS_7_GROUP.
    CO22      LABELS_7_GROUP.
    CO23      LABELS_7_GROUP.
    CO24      LABELS_7_GROUP.
    CO25      LABELS_7_GROUP.
    CO26      LABELS_7_GROUP.
    CO31      LABELS_7_GROUP.
    CO32      LABELS_7_GROUP.
    CO33      LABELS_7_GROUP.
    CO34      LABELS_7_GROUP.
    CO35      LABELS_7_GROUP.
    CO36      LABELS_7_GROUP.
    CO41      LABELS_7_GROUP.
    CO42      LABELS_7_GROUP.
    CO43      LABELS_7_GROUP.
    CO44      LABELS_7_GROUP.
    CO45      LABELS_7_GROUP.
    CO46      LABELS_7_GROUP.
    CO51      LABELS_7_GROUP.
    CO52      LABELS_7_GROUP.
    CO53      LABELS_7_GROUP.
    CO54      LABELS_7_GROUP.
    CO55      LABELS_7_GROUP.
    CO56      LABELS_7_GROUP.
    CO61      LABELS_7_GROUP.
    CO62      LABELS_7_GROUP.
    CO63      LABELS_7_GROUP.
    CO64      LABELS_7_GROUP.
    CO65      LABELS_7_GROUP.
    CO66      LABELS_7_GROUP.
    CO71      LABELS_7_GROUP.
    CO72      LABELS_7_GROUP.
    CO73      LABELS_7_GROUP.
    CO74      LABELS_7_GROUP.
    CO75      LABELS_7_GROUP.
    CO76      LABELS_7_GROUP.
    CO81      LABELS_7_GROUP.
    CO82      LABELS_7_GROUP.
    CO83      LABELS_7_GROUP.
    CO84      LABELS_7_GROUP.
    CO85      LABELS_7_GROUP.
    CO86      LABELS_7_GROUP.
    SENT      LABELS_8_GROUP.
    SGRP      LABELS_8_GROUP.
    SSUP      LABELS_8_GROUP.
    SCLI      LABELS_8_GROUP.
    SCOM      LABELS_8_GROUP.
    SUNI      LABELS_8_GROUP.
    SGMT      LABELS_8_GROUP.
    SPRO      LABELS_8_GROUP.
    SEXB      LABELS_8_GROUP.
    NACE2_N   LABELS_9_GROUP.
    SIZE98_N  LABELS_10_GROUP.
    SIZE00_N  LABELS_11_GROUP.
    ;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Save data to a sas type file ---                                           ;

DATA dirout.&sasfile;

    SET sasimport;

RUN;
